#
# spec file for package merkuro
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude qt6qmlimport\\((org\\.kde\\.merkuro|org\\.kde\\.raven).*

%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define kpim6_version 6.3.2
%define plasma6_version 6.2.0

%bcond_without released
Name:           merkuro
Version:        24.12.2
Release:        1.1
Summary:        Calendar Application
License:        GPL-3.0-only
URL:            https://apps.kde.org/merkuro.calendar
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6CalendarCore) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 1.2.1
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(KPim6Akonadi) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiCalendar) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiContactCore) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiMime) >= %{kpim6_version}
BuildRequires:  cmake(KPim6CalendarUtils) >= %{kpim6_version}
BuildRequires:  cmake(KPim6IdentityManagementQuick) >= %{kpim6_version}
BuildRequires:  cmake(KPim6MailCommon) >= %{kpim6_version}
BuildRequires:  cmake(KPim6MailTransport) >= %{kpim6_version}
BuildRequires:  cmake(KPim6MimeTreeParserCore) >= %{kpim6_version}
BuildRequires:  cmake(Plasma) >= %{plasma6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Location) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickTest) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  pkgconfig(gpgme)
Requires:       kalendarac
Requires:       kdepim-addons
Requires:       kdepim-runtime
# No automatic qmlimport requires for embedded resources :-/
Requires:       kf6-kdeclarative-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-ksvg-imports >= %{kf6_version}
Requires:       kidentitymanagement-imports
Requires:       libPlasma6 >= %{plasma6_version}
Requires:       libplasma6-components >= %{plasma6_version}
Requires:       mimetreeparser-imports
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-location >= %{qt6_version}
Requires:       qt6-positioning-imports >= %{qt6_version}
Provides:       kalendar = %{version}
Obsoletes:      kalendar < %{version}
# merkuro has a runtime dependency on QtWebEngine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64

%description
Calendar application using Akonadi to sync with external services (NextCloud, GMail, ...).

%package plasmoid
Summary:        Plasma widget to view address book contacts
Requires:       merkuro = %{version}
Supplements:    (merkuro and plasma6-workspace)
Provides:       kalendar-plasmoid = %{version}
Obsoletes:      kalendar-plasmoid < %{version}

%description plasmoid
This package provides a Plasma widget to view address book contacts.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf6_applicationsdir}/org.kde.merkuro.calendar.desktop
%{_kf6_applicationsdir}/org.kde.merkuro.contact.desktop
%{_kf6_applicationsdir}/org.kde.merkuro.mail.desktop
%{_kf6_applicationsdir}/org.kde.merkuro.desktop
%{_kf6_appstreamdir}/org.kde.merkuro.calendar.metainfo.xml
%{_kf6_appstreamdir}/org.kde.merkuro.contact.metainfo.xml
%{_kf6_appstreamdir}/org.kde.merkuro.mail.metainfo.xml
%{_kf6_appstreamdir}/org.kde.merkuro.metainfo.xml
%{_kf6_bindir}/merkuro-calendar
%{_kf6_bindir}/merkuro-contact
%{_kf6_bindir}/merkuro-mail
%{_kf6_debugdir}/akonadi.quick.categories
%{_kf6_debugdir}/merkuro.categories
%{_kf6_debugdir}/merkuro.contact.categories
%{_kf6_iconsdir}/hicolor/*/apps/org.kde.merkuro.*.png
%{_kf6_qmldir}/org/kde/akonadi/
%{_kf6_qmldir}/org/kde/merkuro/
%{_kf6_libdir}/libMerkuroComponents.so.*
%{_kf6_libdir}/libMerkuroComponents.so
%{_kf6_libdir}/libmerkuro_contact.so.*
%{_kf6_libdir}/libmerkuro_contact.so
%{_kf6_notificationsdir}/merkuro.mail.notifyrc

%files plasmoid
%dir %{_kf6_plasmadir}/plasmoids
%{_kf6_appstreamdir}/org.kde.merkuro.contact.appdata.xml
%{_kf6_plasmadir}/plasmoids/org.kde.merkuro.contact

%files lang -f %{name}.lang

%changelog
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Wed Dec 18 2024 Christophe Marin <christophe@krop.fr>
- Update runtime requirements
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Too many changes since 24.11.80, only listing bugfixes:
  * Install merkuro_contact_plugin shared library (kde#496347)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Compile contacts plugin metadata in the actual QML plugin, not in the shared library. (kde#491808)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix adding new incidence in day grid view
  * Fix use of DayMouseArea (now DayTapHandler) in hourly view-based views
  * Center alignment of text on incidence-less month list day entries
  * Match top and bottom margins for month list incidence items
  * Rename DayMouseArea to DayTapHandler
  * Fix double opening of incidence add window when double-clicking day grid view square
  * Replace DayMouseArea as key delegate in BasicMonthListView with background rectangle
  * Fix uses of DayMouseArea in BasicMonthListView
  * Convert DayMouseArea into a TapHandler
  * Fix tag and name filtering incidences in calendar views
  * Fix references to non-existent openNewSubTodoEditorDialog
  * Once collection combo box model starts receiving collections, set a valid default collection by default
  * Re-enable geolocation components in the incidence editor page
  * Reenable use of map in incidence info contents
  * Fix import of Calendar in LocationMap
  * Adapt LocationMap to Qt6
  * Fix broken Calendar references in task completion slider onMoved handler
  * Fix incidence info popup positioning
  * Add missing window parameter to onCreateNew... handlers in calendar main
  * Fix error in incidenceinfodrawer in main caused by null currentItem in pageStack
  * Fix workaround for incidence info drawer getting cut off when menu bar loaded
  * Fix alignment of incidence info drawer header text
  * Fix references to removed CalendarUiUtils.setUpAdd function
  * Rename InfiniteCalendarViewModel to InfiniteMerkuroCalendarViewModel
  * Fix showing/hiding of hamburger menu in Calendar main drawer
  * Fix contact config
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Don't register contactconfig manually
  * Compile contacts plugin metadata in the actual QML plugin, not in the shared library. (kde#491808)
  * Add missing GENERATE_PLUGIN_SOURCE to merkuro_contact_plugin
- Drop patch, merged upstream:
  * 0001-Add-missing-GENERATE_PLUGIN_SOURCE-to-merkuro_contac.patch
* Wed Aug 28 2024 Christophe Marin <christophe@krop.fr>
- Add upstream fix (boo#1229847):
  * 0001-Add-missing-GENERATE_PLUGIN_SOURCE-to-merkuro_contac.patch
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * MonthView: Update Basic grid when changing months (kde#477161)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * DateTimeState: Use locale for firstDayOfWeek
  * MonthView: Update Basic grid when changing months (kde#477161)
  * Fix cliping in Schedule view
  * HourlyView: Use Calendar.DateTimeState
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * prevents the recurrence end date combo from eliding
  * Make delete dialog background scale with content
  * Ensure window is not closed when last job is run
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix wrong weekday label of Chinese locale when length set to letter only (M) (kde#450571)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Fix menubar display
  * Fix translated shortcut
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Complement metainfo.xml
  * Rework delete incidence dialog
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Add back no display in mail desktop file
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Fix wrong bug url (kde#477373)
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: let appstream set version. refresh dependencies.
  * Ensure we mark element as selected in contact list
  * Typo in reuse for snapcraft.yaml
  * Add snapcraft.yaml to reuse.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix more issue with wrong date due to timezone
  * Fix shifting of date by one day/month (kde#473866)
  * Fix displaying of Basic HourlyView
  * DateUtils: Trim userProvidedYear to remove whitespace before parsing
  * Fix invalid parent collection error
  * fix triggering mailto: and tel: actions twice
  * fixes bug in photoEditor.qml
  * Fix crash when running merkuro with other locales (kde#474191)
  * Fix adding new contact (kde#474380)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix ViewMenu.qml
  * Fix segfault on launch (kde#473618)
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Fix collapsed status of collectionHeadingItem
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- kalendar was renamed to merkuro
- Update to 23.07.80
  * New feature release
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Store reminder times to the correct variable (kde#470288)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Move RemindersModel to calendar module
  * Simplify MultiDayIncidenceModel
  * Use grouped property
  * Modernize DayGridView
  * BasicMonthGridView.qml: Use const instead of let
  * Use strict equality for DayGridViewIncidenceDelegate.isInCurrentMonth
  * Remove usage of KCalPrefs
  * Use Akonadi::Collection::Id to store color keys
  * Improve retrival of color from incidence
  * Get collection color directly from collection when possible in IncidenceOccurrenceModel
  * Fix wrong colour being set in color cache when generating it is required
  * Disable capturing hover events globally
  * Fix bugs in IncidenceInfoContents
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Remove qml debugger
  * Fix incidenceoccurrencemodel tests
  * Fix checking if a non existing calendar (kde#463739)
  * Fix "Custom" reminder option showing as "On Event Start"
  * Fix crashes in incidenceoccurrencemodel (kde#466063)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Use qmlimport dependencies for public org.kde.kalendar.*
- Drop requires on nonexisting -import subpackage
- Install the plasmoid with kalendar if plasma5-workspace is installed
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Fri Aug 19 2022 Christophe Giboudeaux <christophe@krop.fr>
- Merge -imports and the main kalendar package.
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Thu Mar 24 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Kalendar is now released with other KDE Gear.
- Drop obsolete patch:
  * 0001-Use-categorized-logging-in-the-reminder-daemon.patch
* Sat Feb 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.0.0
- Add patch to avoid excessive logging:
  * 0001-Use-categorized-logging-in-the-reminder-daemon.patch
* Sat Oct 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Initial packaging
